@@ -32,11 +32,14 @@
 #include <string>
 #include <set>
 
+/*!\file*/
 namespace gcu
 {
 
 class Application;
 class Dialog;
+class Molecule;
+class Residue;
 
 /*!\class Document gcu/document.h
 This class is the base document class.
@@ -47,7 +50,7 @@ friend class Object;
 friend class Dialog;
 public:
 /*!
-@param App: the Appllcation which owns the new document.
+@param App the Appllcation which owns the new document.
 
 The default constructor. Creates an empty document.
 */
@@ -60,7 +63,7 @@ The destructor of Document.
 public:
 
 /*!
-@param id: the original id to tranlate
+@param id the original id to tranlate
 
 When pasting, objects added to the document might have the same Id as objects already existing. In such cases, the document
 maintains a table to update links using Ids as identifiers. GetTranslatedId returns
@@ -69,7 +72,7 @@ the translated id corresponding to the parameter id.
 	std::string& GetTranslatedId (const char* id) {return m_TranslationTable[id];}
 
 /*!
-@param Id: the entry to remove
+@param Id the entry to remove
 
 When pasting, objects added to the document might have the same Id as objects already existing. In such cases, the document
 maintains a table to update links using Ids as identifiers. The EraseTranslationTable method removes thenentry correspondig to id.
@@ -96,8 +99,39 @@ to avoid errors on the next paste event.
 */
 	std::string &GetTitle () {return m_Title;}
 
+/*!
+@param pObject an object needing some update.
+
+The gcu::Document class just stores dirty objects, but don't do anything with them. Derived classes
+need to implement that, if meaningful.
+*/
 	void NotifyDirty (Object* pObject) {m_DirtyObjects.insert (pObject);}
+/*!
+Saves the document. Need to be overloaded by derived class if meaningful. Default
+implementation doesn't do anything.
+*/
 	virtual void Save () const {;}
+/*!
+@param name the name of the new residue.
+@param symbol the symbol of the new residue.
+@param molecule a molecule with a pseudo atom which describes the structure
+of the residue.
+
+This methodshould be overloaded by derived classes necessitating it. Default
+implementation just returns NULL.
+@return the new Residue on success or NULL.
+*/
+	virtual Residue *CreateResidue (char const *name, char const *symbol, Molecule *molecule);
+/*!
+@param symbol the symbol for which a Residue* is searched.
+@param ambiguous where to store the boolean telling if the symbol is ambiguous
+or NULL.
+
+Documents might own not global residues with the samesymbol or name
+but a different meaning from the standard residue.
+@return the Residue* found or NULL.
+*/
+	virtual Residue const *GetResidue (char const *symbol, bool *ambiguous = NULL);
 
 private:
 
@@ -121,6 +155,9 @@ The document title.
 */
 	std::string m_Title;
 
+/*!
+		 The set of dirty objects, see gcu::Document::NotifyDirty.
+*/
 	std::set<Object*> m_DirtyObjects;
 
 /*!\var m_App
