@@ -345,7 +345,7 @@ void gcpResiduesDlg::Remove ()
 
 bool gcpResiduesDlg::Close ()
 {
-	Destroy ();
+	Dialog::Destroy ();
 	return true;
 }
 
@@ -437,12 +437,14 @@ void gcpResiduesDlg::OnCurChanged ()
 	gtk_entry_set_text (m_SymbolEntry, sy.c_str ());	
 	m_Document->Clear ();
 	m_Document->LoadObjects (m_Residue->GetMolNode ());
-	double r =  m_Document->GetMedianBondLength () / m_Document->GetTheme ()->GetBondLength ();
+	double r =  m_Document->GetTheme ()->GetBondLength () / m_Document->GetMedianBondLength ();
 	if (fabs (r - 1.) > .0001) { 
 		Matrix2D m (r, 0., 0., r);
 		m_Document->Transform2D (m, 0., 0.);
 		m_Document->GetView ()->Update (m_Document);
+		m_Document->GetView ()->EnsureSize ();
 	}
+	m_Document->GetView ()->EnsureSize ();
 	m_Atom = dynamic_cast <gcpPseudoAtom *> (m_Document->GetDescendant ("a1"));
 	map<gcu::Atom*, gcu::Bond*>::iterator j;
 	m_Atom->GetFirstBond (j);
@@ -466,3 +468,11 @@ void gcpResiduesDlg::OnNameActivate ()
 	m_ValidName = strlen (text) > 0;
 	gtk_widget_set_sensitive (m_SaveBtn, m_ValidName && m_ValidSymbols);
 }
+
+void gcpResiduesDlg::OnNewResidue (gcp::Residue *res)
+{
+	map<string, bool> const &symbols = res->GetSymbols ();
+	map<string, bool>::const_iterator i = symbols.begin (), end = symbols.end ();
+	for (i = symbols.begin (); i != end; i++)
+		gtk_combo_box_append_text (m_CurBox, (*i).first.c_str ());
+}
